##
##  kakoune.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2019 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         kakoune
Summary:      Vi-style Text Editor
URL:          http://kakoune.org/
Vendor:       Biokoda
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Editor
License:      MPL
Version:      20190305
Release:      20190305

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/kakoune/kakoune-%{version}.tar.xz
Patch0:       kakoune.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc, gcc::with_cxx = yes, asciidoc
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  boost, ncurses
PreReq:       boost, ncurses

%description
    Kakoune is a code editor heavily inspired by Vim, as such most
    of its commands are similar to vi's ones, and it shares Vi's
    "keystrokes as a text editing language" model. Kakoune can operate
    in two modes, normal and insertion. In insertion mode, keys are
    directly inserted into the current buffer. In normal mode, keys are
    used to manipulate the current selection and to enter insertion
    mode. Kakoune has a strong focus on interactivity, most commands
    provide immediate and incremental results, while still being
    competitive (as in keystroke count) with Vim. Kakoune works on
    selections, which are oriented, inclusive range of characters,
    selections have an anchor and a cursor character. Most commands
    move both of them, except when extending selection where the anchor
    character stays fixed and the cursor one moves around.

%track
    prog kakoune = {
        version   = %{version}
        url       = http://download.openpkg.org/components/versioned/kakoune/
        regex     = kakoune-(__VER__)\.tar\.xz
    }

%prep
    %setup -q -n kakoune
    %patch -p0

%build
    cd src
    %{l_make} %{l_mflags} \
        PREFIX=%{l_prefix} \
        CXX="%{l_cxx} %{l_cxxflags -O}"

%install
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}
    ( cd src
      %{l_make} %{l_mflags} \
          PREFIX=%{l_prefix} \
          DESTDIR=$RPM_BUILD_ROOT \
          install
    ) || exit $?
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

